==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/EntityRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Entity;
import microsoft.dynamics.crm.entity.collection.request.EntityanalyticsconfigCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SolutioncomponentconfigurationCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class EntityRequest extends com.github.davidmoten.odata.client.EntityRequest<Entity> {

    public EntityRequest(ContextPath contextPath, Optional<Object> value) {
        super(Entity.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SolutioncomponentconfigurationCollectionRequest entity_solutioncomponentconfiguration() {
        return new SolutioncomponentconfigurationCollectionRequest(
                        contextPath.addSegment("entity_solutioncomponentconfiguration"), Optional.empty());
    }

    public SolutioncomponentconfigurationRequest entity_solutioncomponentconfiguration(String solutioncomponentconfigurationid) {
        return new SolutioncomponentconfigurationRequest(contextPath.addSegment("entity_solutioncomponentconfiguration").addKeys(new NameValue(solutioncomponentconfigurationid.toString())), Optional.empty());
    }

    public EntityanalyticsconfigCollectionRequest entity_entityanalyticsconfig() {
        return new EntityanalyticsconfigCollectionRequest(
                        contextPath.addSegment("entity_entityanalyticsconfig"), Optional.empty());
    }

    public EntityanalyticsconfigRequest entity_entityanalyticsconfig(String entityanalyticsconfigid) {
        return new EntityanalyticsconfigRequest(contextPath.addSegment("entity_entityanalyticsconfig").addKeys(new NameValue(entityanalyticsconfigid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.45-sources.jar: microsoft/dynamics/crm/entity/request/EntityRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Entity;
import microsoft.dynamics.crm.entity.collection.request.EntityanalyticsconfigCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SolutioncomponentconfigurationCollectionRequest;

@JsonIgnoreType
public class EntityRequest extends com.github.davidmoten.odata.client.EntityRequest<Entity> {

    public EntityRequest(ContextPath contextPath, Optional<Object> value) {
        super(Entity.class, contextPath, value);
    }

    public SolutioncomponentconfigurationCollectionRequest entity_solutioncomponentconfiguration() {
        return new SolutioncomponentconfigurationCollectionRequest(
                        contextPath.addSegment("entity_solutioncomponentconfiguration"), Optional.empty());
    }

    public SolutioncomponentconfigurationRequest entity_solutioncomponentconfiguration(String solutioncomponentconfigurationid) {
        return new SolutioncomponentconfigurationRequest(contextPath.addSegment("entity_solutioncomponentconfiguration").addKeys(new NameValue(solutioncomponentconfigurationid.toString())), Optional.empty());
    }

    public EntityanalyticsconfigCollectionRequest entity_entityanalyticsconfig() {
        return new EntityanalyticsconfigCollectionRequest(
                        contextPath.addSegment("entity_entityanalyticsconfig"), Optional.empty());
    }

    public EntityanalyticsconfigRequest entity_entityanalyticsconfig(String entityanalyticsconfigid) {
        return new EntityanalyticsconfigRequest(contextPath.addSegment("entity_entityanalyticsconfig").addKeys(new NameValue(entityanalyticsconfigid.toString())), Optional.empty());
    }

}
